@@ -4,7 +4,7 @@ library(MASS)
 library(RODBC)
 
 mixsep <- function(){
-  version <- tclVar("0.1-5")
+  version <- tclVar("0.1-6")
   killR <- tclVar("")
   font14bf <- tkfont.create(family = "helvetica", size = 14, weight = "bold")
   font9bf <- tkfont.create(family = "helvetica", size = 9, weight = "bold")
@@ -692,6 +692,20 @@ mixsep <- function(){
       tkgrid(tklabel(colFrame,text="bp"),column=0,row=6,sticky="w")
       resetBP <- tklabel(colFrame,text="[RESET]",font=font7,foreground="blue")
       tkgrid(resetBP,column=1,row=6,sticky="w")
+
+      kitFrame <- tkframe(frame2)
+      kitHead <- tkframe(kitFrame)
+      kitSelect <- tkframe(kitFrame)
+      
+      kit.ID <- tkradiobutton(kitSelect,variable=kit,value="ID",text="Identifiler",state="disabled")
+      kit.Mini <- tkradiobutton(kitSelect,variable=kit,value="Mini",text="MiniFiler",state="disabled")
+      kit.NGM <- tkradiobutton(kitSelect,variable=kit,value="NGM",text="NGM (SElect)",state="disabled")
+      kit.Plus <- tkradiobutton(kitSelect,variable=kit,value="Plus",text="Profiler Plus",state="disabled")
+      kit.COfiler <- tkradiobutton(kitSelect,variable=kit,value="COfiler",text="COfiler",state="disabled")
+      kit.SGM <- tkradiobutton(kitSelect,variable=kit,value="SGM",text="SGM Plus",state="disabled")
+      kit.SE <- tkradiobutton(kitSelect,variable=kit,value="SE",text="SEfiler",state="disabled")
+      kit.Profiler <- tkradiobutton(kitSelect,variable=kit,value="Profiler",text="Profiler",state="disabled")
+#      kit.ESI17 <- tkradiobutton(kitSelect,variable=kit,value="ESI17",text="ESI17",state="disabled")
       kitNormal <- function(){
         tkconfigure(kit.ID,state="normal")
         tkconfigure(kit.Mini,state="normal")
@@ -701,7 +715,7 @@ mixsep <- function(){
         tkconfigure(kit.SGM,state="normal")
         tkconfigure(kit.SE,state="normal")
         tkconfigure(kit.Profiler,state="normal")
-        tkconfigure(kit.ESI17,state="normal")
+#        tkconfigure(kit.ESI17,state="normal")
       }
       kitDisable <- function(){
         tkconfigure(kit.ID,state="disabled")
@@ -712,7 +726,7 @@ mixsep <- function(){
         tkconfigure(kit.SGM,state="disabled")
         tkconfigure(kit.SE,state="disabled")
         tkconfigure(kit.Profiler,state="disabled")
-        tkconfigure(kit.ESI17,state="disabled")
+#        tkconfigure(kit.ESI17,state="disabled")
       }
       tkbind(resetBP,"<Button-1>",function(){kitNormal();tcl("set",bpCol,"0")})
       tkgrid(tklabel(colFrame,text="Dye"),column=0,row=7,sticky="w")
@@ -774,25 +788,24 @@ mixsep <- function(){
       tkgrid(tklabel(colFrame,text=""))
       tkgrid(colFrame)
 
-      kitFrame <- tkframe(frame2)
-      kitHead <- tkframe(kitFrame)
       tkgrid(tklabel(kitHead,text="If information about basepair (bp) and fluorescent dye are missing please select the appropriate kit from the list below"),
              columnspan=3,sticky="w",row=0)
       tkgrid(kitHead)
-      kitSelect <- tkframe(kitFrame)
+
       tkgrid(tklabel(kitSelect,text="Applied Biosystems",font=font9bf),sticky="w",column=0,row=1)
-      tkgrid(kit.ID <- tkradiobutton(kitSelect,variable=kit,value="ID",text="Identifiler",state="disabled"),sticky="w",column=0,row=2)
-      tkgrid(kit.Mini <- tkradiobutton(kitSelect,variable=kit,value="Mini",text="MiniFiler",state="disabled"),sticky="w",column=0,row=3)
-      tkgrid(kit.NGM <- tkradiobutton(kitSelect,variable=kit,value="NGM",text="NGM (SElect)",state="disabled"),sticky="w",column=0,row=4)
-      tkgrid(kit.Plus <- tkradiobutton(kitSelect,variable=kit,value="Plus",text="Profiler Plus",state="disabled"),sticky="w",column=0,row=5)
-      tkgrid(kit.COfiler <- tkradiobutton(kitSelect,variable=kit,value="COfiler",text="COfiler",state="disabled"),sticky="w",column=0,row=6)
-      tkgrid(kit.SGM <- tkradiobutton(kitSelect,variable=kit,value="SGM",text="SGM Plus",state="disabled"),sticky="w",column=0,row=7)
-      tkgrid(kit.SE <- tkradiobutton(kitSelect,variable=kit,value="SE",text="SEfiler",state="disabled"),sticky="w",column=0,row=8)
-      tkgrid(kit.Profiler <- tkradiobutton(kitSelect,variable=kit,value="Profiler",text="Profiler",state="disabled"),sticky="w",column=0,row=9)
+      tkgrid(kit.ID,sticky="w",column=0,row=2)
+      tkgrid(kit.Mini,sticky="w",column=0,row=3)
+      tkgrid(kit.NGM,sticky="w",column=0,row=4)
+      tkgrid(kit.Plus,sticky="w",column=0,row=5)
+      tkgrid(kit.COfiler,sticky="w",column=0,row=6)
+      tkgrid(kit.SGM,sticky="w",column=0,row=7)
+      tkgrid(kit.SE,sticky="w",column=0,row=8)
+      tkgrid(kit.Profiler,sticky="w",column=0,row=9)
 #      tkgrid(tkradiobutton(kitSelect,variable=kit,value="Y",text="Yfiler"))
       tkgrid(tklabel(kitSelect,text="    ",font=font9bf),sticky="w",column=1,row=1)
       tkgrid(tklabel(kitSelect,text="Promega",font=font9bf),sticky="w",column=2,row=1)
-      tkgrid(kit.ESI17 <- tkradiobutton(kitSelect,variable=kit,value="ESI17",text="ESI17",state="disabled"),sticky="w",column=2,row=2)
+      tkgrid(tklabel(kitSelect,text="Currently not available",font=font9it),sticky="w",column=2,row=2)
+#      tkgrid(kit.ESI17,sticky="w",column=2,row=2)
 #      tkgrid(tkradiobutton(kitSelect,variable=kit,value="pkit1",text="Promega kit 1"),sticky="w",column=2,row=3)
 #      tkgrid(tkradiobutton(kitSelect,variable=kit,value="pkit2",text="Promega kit 2"),sticky="w",column=2,row=4)
       tkgrid(kitSelect)
